==> cider_0.16.0+dfsg.orig.tar.xz: cider-0.16.0+dfsg/doc/additional_resources.md <==
## Quick reference

A single-page quick reference PDF for CIDER commands is available
[here](cider-refcard.pdf). This PDF can be created manually by running
`pdflatex` on [the CIDER refcard LaTeX file](cider-refcard.tex).

## Demos

* [Deep Dive into CIDER](https://www.youtube.com/watch?v=aYA4AAjLfT0) - an overview of CIDER's essential features
* [Emacs & Clojure, A Lispy Love Affair](https://www.youtube.com/watch?v=O6g5C4jUCUc) - an overview of all popular Emacs packages for Clojure development (including CIDER)

## Presentations

* [The Evolution of the Emacs tooling for Clojure](https://www.youtube.com/watch?v=4X-1fJm25Ww&list=PLZdCLR02grLoc322bYirANEso3mmzvCiI&index=6) -
  presented at Clojure/conj 2014; dedicated to the origin and the architecture
  of CIDER and related tooling
* [CIDER: The Journey so Far and the Road Ahead](https://skillsmatter.com/skillscasts/7225-cider-the-journey-so-far-and-the-road-ahead) -
  presented at ClojureX 2015; dedicated to CIDER 0.9 and 0.10 and the future of
  the project.
* [A Few Pints of CIDER](https://www.youtube.com/watch?v=3Q7APa2Htns&list=PLPgnbBCmP6ZMfHPJ4yMwuoLEZvEe5LVe8) - presented at Clojure Remote 2016; dedicated
to CIDER 0.11; features a 10-minute live demo of some cool CIDER features.
* [CIDER: Inside the Brewery](https://www.youtube.com/watch?v=8wLwbpCxRf0&list=PLZdCLR02grLq4e8-1P2JNHBKUOLFTX3kb) - presented at Clojure/West 2016;
dedicated to CIDER 0.12.

## Podcasts

* [Cognicast's episode on CIDER](http://blog.cognitect.com/cognicast/080)

==> cider_0.19.0+dfsg.orig.tar.xz: cider-0.19.0+dfsg/doc/additional_resources.md <==
## Quick reference

A single-page quick reference PDF for CIDER commands is available
[here](cider-refcard.pdf). This PDF can be created manually by running
`pdflatex` on [the CIDER refcard LaTeX file](cider-refcard.tex).

## Demos

* [Deep Dive into CIDER](https://www.youtube.com/watch?v=aYA4AAjLfT0) - an overview of CIDER's essential features
* [Emacs & Clojure, A Lispy Love Affair](https://www.youtube.com/watch?v=O6g5C4jUCUc) - an overview of all popular Emacs packages for Clojure development (including CIDER)

## Presentations

* [The Evolution of the Emacs tooling for Clojure](https://www.youtube.com/watch?v=4X-1fJm25Ww&list=PLZdCLR02grLoc322bYirANEso3mmzvCiI&index=6) -
  presented at Clojure/conj 2014; dedicated to the origin and the architecture
  of CIDER and related tooling
* [CIDER: The Journey so Far and the Road Ahead](https://skillsmatter.com/skillscasts/7225-cider-the-journey-so-far-and-the-road-ahead) -
  presented at ClojureX 2015; dedicated to CIDER 0.9 and 0.10 and the future of
  the project.
* [A Few Pints of CIDER](https://www.youtube.com/watch?v=3Q7APa2Htns&list=PLPgnbBCmP6ZMfHPJ4yMwuoLEZvEe5LVe8) - presented at Clojure Remote 2016; dedicated
to CIDER 0.11; features a 10-minute live demo of some cool CIDER features.
* [CIDER: Inside the Brewery](https://www.youtube.com/watch?v=8wLwbpCxRf0&list=PLZdCLR02grLq4e8-1P2JNHBKUOLFTX3kb) - presented at Clojure/West 2016;
dedicated to CIDER 0.12.

## Podcasts

* [Cognicast's episode on CIDER](http://blog.cognitect.com/cognicast/080)
* [defn's episode on CIDER](https://soundcloud.com/defn-771544745/36-a-long-glass-of-cider-with-bozhidar-batsov-aka-bbatsov)
